<template>
  <a-card :bordered="false">
    <!-- table区域-begin -->
    <div>
      <a-table
        ref="table"
        size="middle"
        bordered
        rowKey="id"
        :columns="columns"
        :pagination="ipagination"
        :dataSource="dataSource"
        :loading="loading"
        @change="handleTableChange"
      >
        <!-- <span
          slot="workCenterName"
          slot-scope="text"
        >
          <j-ellipsis
            :value="text"
            :length="10"
          />
        </span> -->

      </a-table>
    </div>

  </a-card>
</template>

<script>

import { JeecgListMixin } from '@/mixins/JeecgListMixin'
import JEllipsis from "@/components/jeecg/JEllipsis";
import { deleteAction, getAction } from '@/api/manage'

export default {
  name: "ProcessParametersDetailList",
  mixins: [JeecgListMixin],
  components: {
    JEllipsis,
  },
  data() {
    return {
      disabled: true,
      description: '设备工艺参数',
      val: { processParametersTemplateId: -1 },
      dataSource: [],
      /* 分页参数 */
      ipagination: {
        current: 1,
        pageSize: 5,
        pageSizeOptions: ['5', '10', '20', '30'],
        showTotal: (total, range) => {
          return range[0] + "-" + range[1] + " 共" + total + "条"
        },
        showQuickJumper: true,
        showSizeChanger: true,
        total: 0
      },
      columns: [
        {
          title: '#',
          dataIndex: '',
          key: 'rowIndex',
          align: "center",
          customRender: function (t, r, index) {
            return parseInt(index) + 1;
          },
          width: 50,
        },
        {
          title: '工艺参数编码',
          align: 'center',
          dataIndex: 'processParametersNum',
        },
        {
          title: '工艺参数名称',
          align: 'center',
          dataIndex: 'processParametersName',
        },
        {
          title: '计量单位',
          align: 'center',
          dataIndex: 'unit',
        },
        {
          title: '备注',
          align: 'center',
          dataIndex: 'remark',
        },
      ],

      url: {
        list: '/eam/processParametersTemplateDetail/listByProcessParametersTemplateId',
      },
    }
  },

  mounted() {
    this.$bus.$on('refreshChildPage', (data) => {
      this.val = data
      this.loadData2("1", data);
    })
  },

  watch: {
    dataSource() {
      this.$bus.$emit('processParametersDataSource', this.dataSource);
    },
  },

  methods: {

    handleTableChange(pagination, filters, sorter) {
      //分页、排序、筛选变化时触发
      //TODO 筛选
      if (Object.keys(sorter).length > 0) {
        this.isorter.column = sorter.field;
        this.isorter.order = "ascend" == sorter.order ? "asc" : "desc"
      }
      this.ipagination = pagination;
      this.loadData();
    },
    loadData() {
      this.loadData2(this.ipagination.current, this.val)
    },

    loadData2(arg, val) {
      if (arg === 1) {
        this.ipagination.current = 1;
      }
      var params = this.getQueryParams();
      if (val != null) {
        params.processParametersTemplateId = val.processParametersTemplateId
      } else {
        params.processParametersTemplateId = "-1"
      }
      this.loading = true;
      getAction(this.url.list, params).then((res) => {
        if (res.success) {
          this.dataSource = res.result.records;
          this.ipagination.total = res.result.total;
        }
        this.loading = false;
      })
    },

  },

}
</script>

<style lang='less' scoped>
@import '~@assets/less/common.less';
/deep/ .frozenRowClass {
  color: #c9c9c9;
}
.success {
  color: green;
}
.error {
  color: red;
}
.fontweight {
  font-weight: bold;
}
.fontweightSuccess {
  color: green;
  font-weight: bold;
}
.fontweightfrozen {
  color: #c9c9c9;
  font-weight: bold;
}
.ant-card {
  margin-left: -30px;
  margin-right: -30px;
}
.fontweightColor {
  font-weight: bold;
  color: red;
}
.ant-card {
  margin-left: -30px;
  margin-right: -30px;
}
</style>